NAME = "bluer_agent"

ICON = "👾"

DESCRIPTION = f"{ICON} an AI agent."

VERSION = "5.120.1"

REPO_NAME = "bluer-agent"

MARQUEE = "https://github.com/kamangir/assets2/raw/main/bluer-agent/icon.jpg?raw=true"

ALIAS = "@agent"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
