#! /usr/bin/env bash

alias @audio=bluer_agent_audio

alias @chat=bluer_agent_chat

alias @crawl=bluer_agent_crawl

alias @rag=bluer_agent_rag

alias @transcribe=bluer_agent_transcribe

# ignore
alias @agent=bluer_agent
alias @ai_agent=bluer_agent
