docs = [
    {
        "path": "../docs/crawl",
    },
    {
        "path": "../docs/crawl/one.md",
    },
    {
        "path": "../docs/crawl/two.md",
    },
    {
        "path": "../docs/crawl/three.md",
    },
]
